@@ -3,7 +3,7 @@ from django.core.files.storage import FileSystemStorage
 from django.utils.module_loading import import_string
 
 
-if hasattr(settings, 'FILE_FORM_TEMP_STORAGE'):
+if hasattr(settings, "FILE_FORM_TEMP_STORAGE"):
     storage_class = import_string(settings.FILE_FORM_TEMP_STORAGE)
 else:
     storage_class = FileSystemStorage
